

set -ex



pip check
cd src
coverage run -m pytest -vv -k 'not (unused_port_fixture or unused_port_factory_fixture or auto_mode_cmdline or test_strict_mode_ignores_trio_fixtures)'
coverage report --fail-under 91
exit 0
